# -*- coding: utf-8 -*-
# Author: WUWUTech
# Contact: wuwu@wuwu.tech
#
# References
#   https://open.feishu.cn/document/ukTMukTMukTM/uITNz4iM1MjLyUzM


TOKEN_TYPE_NONE = 'TOKEN_TYPE_NONE'
TOKEN_TYPE_APP_ACCESS_TOKEN_INTERNAL = 'APP_ACCESS_TOKEN_INTERNAL'

from .http_client import HttpClient
from .feishu_client import FeiShuClient
